@@ -1,12 +1,14 @@
 `fact2dummy` <-
 function (data, all=TRUE, lab="x") 
 {
+#########################################
 	dum.fcn <- function(x, all=TRUE){
-        fine <- model.matrix(~x-1)
+        fine <- model.matrix.lm(~x-1, na.action = "na.pass")
 		colnames(fine) <- levels(x)
 		if(!all) fine <- fine[,-ncol(fine), drop=FALSE]
 		fine
-    }
+	}
+###########################################
 	
 	if(is.null(dim(data))){
 		if(class(data)[1]=="numeric" || class(data)[1]=="integer" || class(data)[1]=="logical") oo <- cbind(1*data)
@@ -40,10 +42,12 @@ function (data, all=TRUE, lab="x")
             # oo <- unlist(out)
             # oo <- matrix(oo, nrow=n)
             # dimnames(oo) <- list(row.names(data), unlist(lapply(out, colnames)))
+		    #cat(unlist(lapply(out, nrow)), fill=T)
 		    oo <- do.call("cbind", out)
 		}
 	}	
 	rownames(oo) <- rownames(data)
 	oo
+	
 }
 
